@@ -174,7 +174,7 @@ void MainWindow::readgtkrc()
     int indeksi = ui->Iconset->findText(icontheme);
     ui->Iconset->setCurrentIndex(indeksi);
 
-    ui->label->setText(tr("Current theme: ") + currenttheme);
+    ui->label->setText(tr("Current theme: ") + currenttheme + "\n" + tr("Tap to change"));
 }
 
 void MainWindow::writeSettings()
@@ -771,11 +771,13 @@ void MainWindow::on_checkBoxActivate_stateChanged(int )
 
 void MainWindow::on_fontimport_triggered()
 {
+    QMaemo5InformationBox::information(this, tr("Select folder containing the fonts you want to import"), QMaemo5InformationBox::DefaultTimeout);
     QString fontdir = QFileDialog::getExistingDirectory(this, "Select folder containing fonts", lastpath, QFileDialog::ShowDirsOnly);
     if (fontdir.isEmpty()) return;
 
     lastpath = fontdir;
     QString varattu2;
+    QString found;
     varattu2 = tr("Importing fonts");
     progress2.setWindowModality(Qt::WindowModal);
     progress2.setWindowTitle(varattu2);
@@ -783,9 +785,29 @@ void MainWindow::on_fontimport_triggered()
     QStringList arguments2;
     arguments2 << "importfontspushed" << fontdir;
     QProcess *process2 = new QProcess(this);
-    connect(process2, SIGNAL(finished(int)), this, SLOT(process2Finished(int)));
     process2->start("/sbin/launchcustomizer", arguments2);
-    progress2.show();
+    process2->waitForFinished();
+
+   QDirIterator directory_walker(lastpath, QDir::Files | QDir::NoSymLinks, QDirIterator::NoIteratorFlags);
+
+   while(directory_walker.hasNext())
+   {
+        directory_walker.next();
+
+        if(directory_walker.fileInfo().completeSuffix() == "ttf" || directory_walker.fileInfo().completeSuffix() == "otf") {
+            QString perse = directory_walker.filePath();
+            QString dest = directory_walker.fileName();
+            QFile::copy(perse, "/home/user/.fonts/" + dest);
+            found = "1";
+
+        }
+
+   }
+   sleep(2);
+   if ( found == "1" )
+   QMaemo5InformationBox::information(this, tr("Font import complete! Restart Theme Customizer to use new fonts."), QMaemo5InformationBox::NoTimeout);
+   else
+   QMaemo5InformationBox::information(this, tr("No .ttf or .otf font files found under: ") + "<br />" + lastpath, QMaemo5InformationBox::NoTimeout);
 }
 
 void MainWindow::process2Finished(int)
@@ -800,7 +822,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-59<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-60<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -1165,3 +1187,17 @@ void MainWindow::on_actionImport_theme_triggered()
     process2->start("/sbin/launchcustomizer", arguments2);
     progress2.show();
 }
+
+void MainWindow::on_label_clicked()
+{
+    QProcess *process2 = new QProcess(this);
+//    connect(process2, SIGNAL(finished(int)), this, SLOT(process2Finished(int)));
+    process2->start("/usr/bin/personalisation_app");
+    process2->waitForFinished();
+    sleep(2);
+    readdirs();
+    oldfonts("/etc/hildon/theme/colors.config");
+    readgtkrc();
+    readSettings();
+    writeSettings();
+}
