@@ -15,6 +15,22 @@
         <source>Use custom (fast) window transitions</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Tap to change</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select folder containing the fonts you want to import</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font import complete! Restart Theme Customizer to use new fonts.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No .ttf or .otf font files found under: </source>
+        <translation type="unfinished"></translation>
+    </message> 
     <message>
         <source>Setting up window transitions</source>
         <translation type="unfinished"></translation>
