@@ -8,6 +8,22 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <source>Tap to change</source>
+        <translation>Klikkaa vaihtaaksesi</translation>
+    </message>
+    <message>
+        <source>Select folder containing the fonts you want to import</source>
+        <translation>Valitse kansio joka sisältää tuotavat fontit</translation>
+    </message>
+    <message>
+        <source>Font import complete! Restart Theme Customizer to use new fonts.</source>
+        <translation>Fonttien tuonti valmis! Käynnistä Theme Customizer uudestaan käyttääksesi uusia fontteja.</translation>
+    </message>
+    <message>
+        <source>No .ttf or .otf font files found under: </source>
+        <translation>Fontteja ei löytynyt kansiosta:</translation>
+    </message>
     <message>
         <source>Use custom (fast) window transitions</source>
         <translation>Käytä muokattuja (nopeita) ikkuna-animaatioita</translation>
